@@ -5,8 +5,8 @@ package checker_test
 import (
 	"testing"
 
+	"github.com/oasdiff/oasdiff/checker"
 	"github.com/stretchr/testify/require"
-	"github.com/tufin/oasdiff/checker"
 )
 
 func TestApiChange_PrettyNotPipedUnix(t *testing.T) {
