@@ -3,8 +3,8 @@ package localizations_test
 import (
 	"testing"
 
+	"github.com/oasdiff/oasdiff/checker/localizations"
 	"github.com/stretchr/testify/require"
-	"github.com/tufin/oasdiff/checker/localizations"
 )
 
 func TestLang_Exists(t *testing.T) {
