@@ -5,11 +5,11 @@ import (
 	"os"
 	"testing"
 
+	"github.com/oasdiff/oasdiff/checker"
+	"github.com/oasdiff/oasdiff/formatters"
+	"github.com/oasdiff/oasdiff/load"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
-	"github.com/tufin/oasdiff/checker"
-	"github.com/tufin/oasdiff/formatters"
-	"github.com/tufin/oasdiff/load"
 )
 
 var gitHubFormatter = formatters.GitHubActionsFormatter{
