@@ -5,10 +5,10 @@ import (
 	"fmt"
 	"text/tabwriter"
 
-	"github.com/tufin/oasdiff/checker"
-	"github.com/tufin/oasdiff/diff"
-	"github.com/tufin/oasdiff/load"
-	"github.com/tufin/oasdiff/report"
+	"github.com/oasdiff/oasdiff/checker"
+	"github.com/oasdiff/oasdiff/diff"
+	"github.com/oasdiff/oasdiff/load"
+	"github.com/oasdiff/oasdiff/report"
 )
 
 type TEXTFormatter struct {
