@@ -8,10 +8,10 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/oasdiff/oasdiff/checker"
+	"github.com/oasdiff/oasdiff/formatters"
+	"github.com/oasdiff/oasdiff/internal"
 	"github.com/stretchr/testify/require"
-	"github.com/tufin/oasdiff/checker"
-	"github.com/tufin/oasdiff/formatters"
-	"github.com/tufin/oasdiff/internal"
 	"gopkg.in/yaml.v3"
 )
 
